# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from ..base_object import BaseObject
from ..types import Location
from ..types import ReplyMarkup


class EditInlineMessageLiveLocation(BaseObject):
    """
    Edits the content of a live location in an inline message sent via a bot; for bots only
    
    Params:
        inline_message_id (:class:`str`)
            Inline message identifier
        
        reply_markup (:class:`ReplyMarkup`)
            The new message reply markup
        
        location (:class:`Location`)
            New location content of the message; may be null. Pass null to stop sharing the live location
        
        heading (:class:`int`)
            The new direction in which the location moves, in degrees; 1-360. Pass 0 if unknown
        
        proximity_alert_radius (:class:`int`)
            The new maximum distance for proximity alerts, in meters (0-100000). Pass 0 if the notification is disabled
        
    """

    ID: str = Field("editInlineMessageLiveLocation", alias="@type")
    inline_message_id: str
    reply_markup: ReplyMarkup
    location: typing.Optional[Location] = None
    heading: int
    proximity_alert_radius: int

    @staticmethod
    def read(q: dict) -> EditInlineMessageLiveLocation:
        return EditInlineMessageLiveLocation.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatReportReason(BaseObject):
    """
    Describes the reason why a chat is reported
    
    """

    ID: str = Field("chatReportReason", alias="@type")


class ChatReportReasonChildAbuse(ChatReportReason):
    """
    The chat has child abuse related content
    
    """

    ID: str = Field("chatReportReasonChildAbuse", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatReportReasonChildAbuse:
        return ChatReportReasonChildAbuse.construct(**q)


class ChatReportReasonCopyright(ChatReportReason):
    """
    The chat contains copyrighted content
    
    """

    ID: str = Field("chatReportReasonCopyright", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatReportReasonCopyright:
        return ChatReportReasonCopyright.construct(**q)


class ChatReportReasonCustom(ChatReportReason):
    """
    A custom reason provided by the user
    
    """

    ID: str = Field("chatReportReasonCustom", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatReportReasonCustom:
        return ChatReportReasonCustom.construct(**q)


class ChatReportReasonFake(ChatReportReason):
    """
    The chat represents a fake account
    
    """

    ID: str = Field("chatReportReasonFake", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatReportReasonFake:
        return ChatReportReasonFake.construct(**q)


class ChatReportReasonPornography(ChatReportReason):
    """
    The chat contains pornographic messages
    
    """

    ID: str = Field("chatReportReasonPornography", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatReportReasonPornography:
        return ChatReportReasonPornography.construct(**q)


class ChatReportReasonSpam(ChatReportReason):
    """
    The chat contains spam messages
    
    """

    ID: str = Field("chatReportReasonSpam", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatReportReasonSpam:
        return ChatReportReasonSpam.construct(**q)


class ChatReportReasonUnrelatedLocation(ChatReportReason):
    """
    The location-based chat is unrelated to its stated location
    
    """

    ID: str = Field("chatReportReasonUnrelatedLocation", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatReportReasonUnrelatedLocation:
        return ChatReportReasonUnrelatedLocation.construct(**q)


class ChatReportReasonViolence(ChatReportReason):
    """
    The chat promotes violence
    
    """

    ID: str = Field("chatReportReasonViolence", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatReportReasonViolence:
        return ChatReportReasonViolence.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import MessageSender
from ..types import SearchMessagesFilter


class SearchChatMessages(BaseObject):
    """
    Searches for messages with given words in the chat. Returns the results in reverse chronological order, i.e. in order of decreasing message_id. Cannot be used in secret chats with a non-empty query (searchSecretMessages should be used instead), or without an enabled message database. For optimal performance the number of returned messages is chosen by the library
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat in which to search messages
        
        query (:class:`str`)
            Query to search for
        
        sender (:class:`MessageSender`)
            If not null, only messages sent by the specified sender will be returned. Not supported in secret chats
        
        from_message_id (:class:`int`)
            Identifier of the message starting from which history must be fetched; use 0 to get results from the last message
        
        offset (:class:`int`)
            Specify 0 to get results from exactly the from_message_id or a negative offset to get the specified message and some newer messages
        
        limit (:class:`int`)
            The maximum number of messages to be returned; must be positive and can't be greater than 100. If the offset is negative, the limit must be greater than -offset. Fewer messages may be returned than specified by the limit, even if the end of the message history has not been reached
        
        filter_ (:class:`SearchMessagesFilter`)
            Filter for message content in the search results
        
        message_thread_id (:class:`int`)
            If not 0, only messages in the specified thread will be returned; supergroups only
        
    """

    ID: str = Field("searchChatMessages", alias="@type")
    chat_id: int
    query: str
    sender: MessageSender
    from_message_id: int
    offset: int
    limit: int
    filter_: SearchMessagesFilter = Field(..., alias='filter')
    message_thread_id: int

    @staticmethod
    def read(q: dict) -> SearchChatMessages:
        return SearchChatMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class MessageSchedulingState(BaseObject):
    """
    Contains information about the time when a scheduled message will be sent
    
    """

    ID: str = Field("messageSchedulingState", alias="@type")


class MessageSchedulingStateSendAtDate(MessageSchedulingState):
    """
    The message will be sent at the specified date
    
    Params:
        send_date (:class:`int`)
            Date the message will be sent. The date must be within 367 days in the future
        
    """

    ID: str = Field("messageSchedulingStateSendAtDate", alias="@type")
    send_date: int

    @staticmethod
    def read(q: dict) -> MessageSchedulingStateSendAtDate:
        return MessageSchedulingStateSendAtDate.construct(**q)


class MessageSchedulingStateSendWhenOnline(MessageSchedulingState):
    """
    The message will be sent when the peer will be online. Applicable to private chats only and when the exact online status of the peer is known
    
    """

    ID: str = Field("messageSchedulingStateSendWhenOnline", alias="@type")

    @staticmethod
    def read(q: dict) -> MessageSchedulingStateSendWhenOnline:
        return MessageSchedulingStateSendWhenOnline.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetLanguagePackStrings(BaseObject):
    """
    Returns strings from a language pack in the current localization target by their keys. Can be called before authorization
    
    Params:
        language_pack_id (:class:`str`)
            Language pack identifier of the strings to be returned
        
        keys (:obj:`list[str]`)
            Language pack keys of the strings to be returned; leave empty to request all available strings
        
    """

    ID: str = Field("getLanguagePackStrings", alias="@type")
    language_pack_id: str
    keys: list[str]

    @staticmethod
    def read(q: dict) -> GetLanguagePackStrings:
        return GetLanguagePackStrings.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CreateSecretChat(BaseObject):
    """
    Returns an existing chat corresponding to a known secret chat
    
    Params:
        secret_chat_id (:class:`int`)
            Secret chat identifier
        
    """

    ID: str = Field("createSecretChat", alias="@type")
    secret_chat_id: int

    @staticmethod
    def read(q: dict) -> CreateSecretChat:
        return CreateSecretChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetBackgrounds(BaseObject):
    """
    Returns backgrounds installed by the user
    
    Params:
        for_dark_theme (:class:`bool`)
            True, if the backgrounds must be ordered for dark theme
        
    """

    ID: str = Field("getBackgrounds", alias="@type")
    for_dark_theme: bool

    @staticmethod
    def read(q: dict) -> GetBackgrounds:
        return GetBackgrounds.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ResendPhoneNumberVerificationCode(BaseObject):
    """
    Re-sends the code to verify a phone number to be added to a user's Telegram Passport
    
    """

    ID: str = Field("resendPhoneNumberVerificationCode", alias="@type")

    @staticmethod
    def read(q: dict) -> ResendPhoneNumberVerificationCode:
        return ResendPhoneNumberVerificationCode.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatMembersFilter(BaseObject):
    """
    Specifies the kind of chat members to return in searchChatMembers
    
    """

    ID: str = Field("chatMembersFilter", alias="@type")


class ChatMembersFilterAdministrators(ChatMembersFilter):
    """
    Returns the owner and administrators
    
    """

    ID: str = Field("chatMembersFilterAdministrators", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatMembersFilterAdministrators:
        return ChatMembersFilterAdministrators.construct(**q)


class ChatMembersFilterBanned(ChatMembersFilter):
    """
    Returns users banned from the chat; can be used only by administrators in a supergroup or in a channel
    
    """

    ID: str = Field("chatMembersFilterBanned", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatMembersFilterBanned:
        return ChatMembersFilterBanned.construct(**q)


class ChatMembersFilterBots(ChatMembersFilter):
    """
    Returns bot members of the chat
    
    """

    ID: str = Field("chatMembersFilterBots", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatMembersFilterBots:
        return ChatMembersFilterBots.construct(**q)


class ChatMembersFilterContacts(ChatMembersFilter):
    """
    Returns contacts of the user
    
    """

    ID: str = Field("chatMembersFilterContacts", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatMembersFilterContacts:
        return ChatMembersFilterContacts.construct(**q)


class ChatMembersFilterMembers(ChatMembersFilter):
    """
    Returns all chat members, including restricted chat members
    
    """

    ID: str = Field("chatMembersFilterMembers", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatMembersFilterMembers:
        return ChatMembersFilterMembers.construct(**q)


class ChatMembersFilterMention(ChatMembersFilter):
    """
    Returns users which can be mentioned in the chat
    
    Params:
        message_thread_id (:class:`int`)
            If non-zero, the identifier of the current message thread
        
    """

    ID: str = Field("chatMembersFilterMention", alias="@type")
    message_thread_id: int

    @staticmethod
    def read(q: dict) -> ChatMembersFilterMention:
        return ChatMembersFilterMention.construct(**q)


class ChatMembersFilterRestricted(ChatMembersFilter):
    """
    Returns users under certain restrictions in the chat; can be used only by administrators in a supergroup
    
    """

    ID: str = Field("chatMembersFilterRestricted", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatMembersFilterRestricted:
        return ChatMembersFilterRestricted.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class RecoveryEmailAddress(BaseObject):
    """
    Contains information about the current recovery email address
    
    Params:
        recovery_email_address (:class:`str`)
            Recovery email address
        
    """

    ID: str = Field("recoveryEmailAddress", alias="@type")
    recovery_email_address: str

    @staticmethod
    def read(q: dict) -> RecoveryEmailAddress:
        return RecoveryEmailAddress.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CallServerType(BaseObject):
    """
    Describes the type of a call server
    
    """

    ID: str = Field("callServerType", alias="@type")


class CallServerTypeTelegramReflector(CallServerType):
    """
    A Telegram call reflector
    
    Params:
        peer_tag (:class:`str`)
            A peer tag to be used with the reflector
        
    """

    ID: str = Field("callServerTypeTelegramReflector", alias="@type")
    peer_tag: str

    @staticmethod
    def read(q: dict) -> CallServerTypeTelegramReflector:
        return CallServerTypeTelegramReflector.construct(**q)


class CallServerTypeWebrtc(CallServerType):
    """
    A WebRTC server
    
    Params:
        username (:class:`str`)
            Username to be used for authentication
        
        password (:class:`str`)
            Authentication password
        
        supports_turn (:class:`bool`)
            True, if the server supports TURN
        
        supports_stun (:class:`bool`)
            True, if the server supports STUN
        
    """

    ID: str = Field("callServerTypeWebrtc", alias="@type")
    username: str
    password: str
    supports_turn: bool
    supports_stun: bool

    @staticmethod
    def read(q: dict) -> CallServerTypeWebrtc:
        return CallServerTypeWebrtc.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class UpgradeBasicGroupChatToSupergroupChat(BaseObject):
    """
    Creates a new supergroup from an existing basic group and sends a corresponding messageChatUpgradeTo and messageChatUpgradeFrom; requires creator privileges. Deactivates the original basic group
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat to upgrade
        
    """

    ID: str = Field("upgradeBasicGroupChatToSupergroupChat", alias="@type")
    chat_id: int

    @staticmethod
    def read(q: dict) -> UpgradeBasicGroupChatToSupergroupChat:
        return UpgradeBasicGroupChatToSupergroupChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class MessageLink(BaseObject):
    """
    Contains an HTTPS link to a message in a supergroup or channel
    
    Params:
        link (:class:`str`)
            Message link
        
        is_public (:class:`bool`)
            True, if the link will work for non-members of the chat
        
    """

    ID: str = Field("messageLink", alias="@type")
    link: str
    is_public: bool

    @staticmethod
    def read(q: dict) -> MessageLink:
        return MessageLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CreateBasicGroupChat(BaseObject):
    """
    Returns an existing chat corresponding to a known basic group
    
    Params:
        basic_group_id (:class:`int`)
            Basic group identifier
        
        force (:class:`bool`)
            If true, the chat will be created without network request. In this case all information about the chat except its type, title and photo can be incorrect
        
    """

    ID: str = Field("createBasicGroupChat", alias="@type")
    basic_group_id: int
    force: bool

    @staticmethod
    def read(q: dict) -> CreateBasicGroupChat:
        return CreateBasicGroupChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TestBytes(BaseObject):
    """
    A simple object containing a sequence of bytes; for testing only
    
    Params:
        value (:class:`str`)
            Bytes
        
    """

    ID: str = Field("testBytes", alias="@type")
    value: str

    @staticmethod
    def read(q: dict) -> TestBytes:
        return TestBytes.construct(**q)



from __future__ import annotations

from collections.abc import Callable
from typing import (
    Any,
    Coroutine,
    TypeVar,
)

from aiotdlib.api import BaseObject
from .handlers import HandlerCallable

SomeUpdate = TypeVar('SomeUpdate', bound=BaseObject)
MiddlewareCallable = Callable[['aiotdlib.Client', SomeUpdate, HandlerCallable], Coroutine[Any, Any, None]]



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetChatMessageTtlSetting(BaseObject):
    """
    Changes the message TTL setting (sets a new self-destruct timer) in a chat. Requires can_delete_messages administrator right in basic groups, supergroups and channels Message TTL setting of a chat with the current user (Saved Messages) and the chat 777000 (Telegram) can't be changed
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        ttl (:class:`int`)
            New TTL value, in seconds; must be one of 0, 86400, 7 * 86400, or 31 * 86400 unless the chat is secret
        
    """

    ID: str = Field("setChatMessageTtlSetting", alias="@type")
    chat_id: int
    ttl: int

    @staticmethod
    def read(q: dict) -> SetChatMessageTtlSetting:
        return SetChatMessageTtlSetting.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .background_fill import BackgroundFill
from ..base_object import BaseObject


class BackgroundType(BaseObject):
    """
    Describes the type of a background
    
    """

    ID: str = Field("backgroundType", alias="@type")


class BackgroundTypeFill(BackgroundType):
    """
    A filled background
    
    Params:
        fill (:class:`BackgroundFill`)
            Description of the background fill
        
    """

    ID: str = Field("backgroundTypeFill", alias="@type")
    fill: BackgroundFill

    @staticmethod
    def read(q: dict) -> BackgroundTypeFill:
        return BackgroundTypeFill.construct(**q)


class BackgroundTypePattern(BackgroundType):
    """
    A PNG or TGV (gzipped subset of SVG with MIME type "application/x-tgwallpattern") pattern to be combined with the background fill chosen by the user
    
    Params:
        fill (:class:`BackgroundFill`)
            Description of the background fill
        
        intensity (:class:`int`)
            Intensity of the pattern when it is shown above the filled background; -100-100. If negative, the pattern color and the filled background colors needs to be inverted
        
        is_moving (:class:`bool`)
            True, if the background needs to be slightly moved when device is tilted
        
    """

    ID: str = Field("backgroundTypePattern", alias="@type")
    fill: BackgroundFill
    intensity: int
    is_moving: bool

    @staticmethod
    def read(q: dict) -> BackgroundTypePattern:
        return BackgroundTypePattern.construct(**q)


class BackgroundTypeWallpaper(BackgroundType):
    """
    A wallpaper in JPEG format
    
    Params:
        is_blurred (:class:`bool`)
            True, if the wallpaper must be downscaled to fit in 450x450 square and then box-blurred with radius 12
        
        is_moving (:class:`bool`)
            True, if the background needs to be slightly moved when device is tilted
        
    """

    ID: str = Field("backgroundTypeWallpaper", alias="@type")
    is_blurred: bool
    is_moving: bool

    @staticmethod
    def read(q: dict) -> BackgroundTypeWallpaper:
        return BackgroundTypeWallpaper.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .message_sender import MessageSender
from ..base_object import BaseObject


class MessageSenders(BaseObject):
    """
    Represents a list of message senders
    
    Params:
        total_count (:class:`int`)
            Approximate total count of messages senders found
        
        senders (:obj:`list[MessageSender]`)
            List of message senders
        
    """

    ID: str = Field("messageSenders", alias="@type")
    total_count: int
    senders: list[MessageSender]

    @staticmethod
    def read(q: dict) -> MessageSenders:
        return MessageSenders.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AddRecentlyFoundChat(BaseObject):
    """
    Adds a chat to the list of recently found chats. The chat is added to the beginning of the list. If the chat is already in the list, it will be removed from the list first
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat to add
        
    """

    ID: str = Field("addRecentlyFoundChat", alias="@type")
    chat_id: int

    @staticmethod
    def read(q: dict) -> AddRecentlyFoundChat:
        return AddRecentlyFoundChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .message_forward_origin import MessageForwardOrigin
from ..base_object import BaseObject


class MessageForwardInfo(BaseObject):
    """
    Contains information about a forwarded message
    
    Params:
        origin (:class:`MessageForwardOrigin`)
            Origin of a forwarded message
        
        date (:class:`int`)
            Point in time (Unix timestamp) when the message was originally sent
        
        public_service_announcement_type (:class:`str`)
            The type of a public service announcement for the forwarded message
        
        from_chat_id (:class:`int`)
            For messages forwarded to the chat with the current user (Saved Messages), to the Replies bot chat, or to the channel's discussion group, the identifier of the chat from which the message was forwarded last time; 0 if unknown
        
        from_message_id (:class:`int`)
            For messages forwarded to the chat with the current user (Saved Messages), to the Replies bot chat, or to the channel's discussion group, the identifier of the original message from which the new message was forwarded last time; 0 if unknown
        
    """

    ID: str = Field("messageForwardInfo", alias="@type")
    origin: MessageForwardOrigin
    date: int
    public_service_announcement_type: str
    from_chat_id: int
    from_message_id: int

    @staticmethod
    def read(q: dict) -> MessageForwardInfo:
        return MessageForwardInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #

from .accept_call import AcceptCall
from .accept_terms_of_service import AcceptTermsOfService
from .add_chat_member import AddChatMember
from .add_chat_members import AddChatMembers
from .add_chat_to_list import AddChatToList
from .add_contact import AddContact
from .add_custom_server_language_pack import AddCustomServerLanguagePack
from .add_favorite_sticker import AddFavoriteSticker
from .add_local_message import AddLocalMessage
from .add_log_message import AddLogMessage
from .add_network_statistics import AddNetworkStatistics
from .add_proxy import AddProxy
from .add_recent_sticker import AddRecentSticker
from .add_recently_found_chat import AddRecentlyFoundChat
from .add_saved_animation import AddSavedAnimation
from .add_sticker_to_set import AddStickerToSet
from .answer_callback_query import AnswerCallbackQuery
from .answer_custom_query import AnswerCustomQuery
from .answer_inline_query import AnswerInlineQuery
from .answer_pre_checkout_query import AnswerPreCheckoutQuery
from .answer_shipping_query import AnswerShippingQuery
from .ban_chat_member import BanChatMember
from .block_message_sender_from_replies import BlockMessageSenderFromReplies
from .can_transfer_ownership import CanTransferOwnership
from .cancel_download_file import CancelDownloadFile
from .cancel_password_reset import CancelPasswordReset
from .cancel_upload_file import CancelUploadFile
from .change_imported_contacts import ChangeImportedContacts
from .change_phone_number import ChangePhoneNumber
from .change_sticker_set import ChangeStickerSet
from .check_authentication_bot_token import CheckAuthenticationBotToken
from .check_authentication_code import CheckAuthenticationCode
from .check_authentication_password import CheckAuthenticationPassword
from .check_authentication_password_recovery_code import CheckAuthenticationPasswordRecoveryCode
from .check_change_phone_number_code import CheckChangePhoneNumberCode
from .check_chat_invite_link import CheckChatInviteLink
from .check_chat_username import CheckChatUsername
from .check_created_public_chats_limit import CheckCreatedPublicChatsLimit
from .check_database_encryption_key import CheckDatabaseEncryptionKey
from .check_email_address_verification_code import CheckEmailAddressVerificationCode
from .check_password_recovery_code import CheckPasswordRecoveryCode
from .check_phone_number_confirmation_code import CheckPhoneNumberConfirmationCode
from .check_phone_number_verification_code import CheckPhoneNumberVerificationCode
from .check_recovery_email_address_code import CheckRecoveryEmailAddressCode
from .check_sticker_set_name import CheckStickerSetName
from .clean_file_name import CleanFileName
from .clear_all_draft_messages import ClearAllDraftMessages
from .clear_imported_contacts import ClearImportedContacts
from .clear_recent_stickers import ClearRecentStickers
from .clear_recently_found_chats import ClearRecentlyFoundChats
from .close import Close
from .close_chat import CloseChat
from .close_secret_chat import CloseSecretChat
from .confirm_qr_code_authentication import ConfirmQrCodeAuthentication
from .create_basic_group_chat import CreateBasicGroupChat
from .create_call import CreateCall
from .create_chat_filter import CreateChatFilter
from .create_chat_invite_link import CreateChatInviteLink
from .create_new_basic_group_chat import CreateNewBasicGroupChat
from .create_new_secret_chat import CreateNewSecretChat
from .create_new_sticker_set import CreateNewStickerSet
from .create_new_supergroup_chat import CreateNewSupergroupChat
from .create_private_chat import CreatePrivateChat
from .create_secret_chat import CreateSecretChat
from .create_supergroup_chat import CreateSupergroupChat
from .create_temporary_password import CreateTemporaryPassword
from .create_voice_chat import CreateVoiceChat
from .delete_account import DeleteAccount
from .delete_all_call_messages import DeleteAllCallMessages
from .delete_all_revoked_chat_invite_links import DeleteAllRevokedChatInviteLinks
from .delete_chat import DeleteChat
from .delete_chat_filter import DeleteChatFilter
from .delete_chat_history import DeleteChatHistory
from .delete_chat_messages_from_user import DeleteChatMessagesFromUser
from .delete_chat_reply_markup import DeleteChatReplyMarkup
from .delete_commands import DeleteCommands
from .delete_file import DeleteFile
from .delete_language_pack import DeleteLanguagePack
from .delete_messages import DeleteMessages
from .delete_passport_element import DeletePassportElement
from .delete_profile_photo import DeleteProfilePhoto
from .delete_revoked_chat_invite_link import DeleteRevokedChatInviteLink
from .delete_saved_credentials import DeleteSavedCredentials
from .delete_saved_order_info import DeleteSavedOrderInfo
from .destroy import Destroy
from .disable_proxy import DisableProxy
from .discard_call import DiscardCall
from .discard_group_call import DiscardGroupCall
from .disconnect_all_websites import DisconnectAllWebsites
from .disconnect_website import DisconnectWebsite
from .download_file import DownloadFile
from .edit_chat_filter import EditChatFilter
from .edit_chat_invite_link import EditChatInviteLink
from .edit_custom_language_pack_info import EditCustomLanguagePackInfo
from .edit_inline_message_caption import EditInlineMessageCaption
from .edit_inline_message_live_location import EditInlineMessageLiveLocation
from .edit_inline_message_media import EditInlineMessageMedia
from .edit_inline_message_reply_markup import EditInlineMessageReplyMarkup
from .edit_inline_message_text import EditInlineMessageText
from .edit_message_caption import EditMessageCaption
from .edit_message_live_location import EditMessageLiveLocation
from .edit_message_media import EditMessageMedia
from .edit_message_reply_markup import EditMessageReplyMarkup
from .edit_message_scheduling_state import EditMessageSchedulingState
from .edit_message_text import EditMessageText
from .edit_proxy import EditProxy
from .enable_proxy import EnableProxy
from .end_group_call_recording import EndGroupCallRecording
from .end_group_call_screen_sharing import EndGroupCallScreenSharing
from .finish_file_generation import FinishFileGeneration
from .forward_messages import ForwardMessages
from .get_account_ttl import GetAccountTtl
from .get_active_live_location_messages import GetActiveLiveLocationMessages
from .get_active_sessions import GetActiveSessions
from .get_all_passport_elements import GetAllPassportElements
from .get_application_config import GetApplicationConfig
from .get_application_download_link import GetApplicationDownloadLink
from .get_archived_sticker_sets import GetArchivedStickerSets
from .get_attached_sticker_sets import GetAttachedStickerSets
from .get_authorization_state import GetAuthorizationState
from .get_auto_download_settings_presets import GetAutoDownloadSettingsPresets
from .get_background_url import GetBackgroundUrl
from .get_backgrounds import GetBackgrounds
from .get_bank_card_info import GetBankCardInfo
from .get_basic_group import GetBasicGroup
from .get_basic_group_full_info import GetBasicGroupFullInfo
from .get_blocked_message_senders import GetBlockedMessageSenders
from .get_callback_query_answer import GetCallbackQueryAnswer
from .get_callback_query_message import GetCallbackQueryMessage
from .get_chat import GetChat
from .get_chat_administrators import GetChatAdministrators
from .get_chat_event_log import GetChatEventLog
from .get_chat_filter import GetChatFilter
from .get_chat_filter_default_icon_name import GetChatFilterDefaultIconName
from .get_chat_history import GetChatHistory
from .get_chat_invite_link import GetChatInviteLink
from .get_chat_invite_link_counts import GetChatInviteLinkCounts
from .get_chat_invite_link_members import GetChatInviteLinkMembers
from .get_chat_invite_links import GetChatInviteLinks
from .get_chat_lists_to_add_chat import GetChatListsToAddChat
from .get_chat_member import GetChatMember
from .get_chat_message_by_date import GetChatMessageByDate
from .get_chat_message_count import GetChatMessageCount
from .get_chat_notification_settings_exceptions import GetChatNotificationSettingsExceptions
from .get_chat_pinned_message import GetChatPinnedMessage
from .get_chat_scheduled_messages import GetChatScheduledMessages
from .get_chat_statistics import GetChatStatistics
from .get_chat_statistics_url import GetChatStatisticsUrl
from .get_chats import GetChats
from .get_commands import GetCommands
from .get_connected_websites import GetConnectedWebsites
from .get_contacts import GetContacts
from .get_countries import GetCountries
from .get_country_code import GetCountryCode
from .get_created_public_chats import GetCreatedPublicChats
from .get_current_state import GetCurrentState
from .get_database_statistics import GetDatabaseStatistics
from .get_deep_link_info import GetDeepLinkInfo
from .get_emoji_suggestions_url import GetEmojiSuggestionsUrl
from .get_external_link import GetExternalLink
from .get_external_link_info import GetExternalLinkInfo
from .get_favorite_stickers import GetFavoriteStickers
from .get_file import GetFile
from .get_file_downloaded_prefix_size import GetFileDownloadedPrefixSize
from .get_file_extension import GetFileExtension
from .get_file_mime_type import GetFileMimeType
from .get_game_high_scores import GetGameHighScores
from .get_group_call import GetGroupCall
from .get_group_call_invite_link import GetGroupCallInviteLink
from .get_group_call_stream_segment import GetGroupCallStreamSegment
from .get_groups_in_common import GetGroupsInCommon
from .get_imported_contact_count import GetImportedContactCount
from .get_inactive_supergroup_chats import GetInactiveSupergroupChats
from .get_inline_game_high_scores import GetInlineGameHighScores
from .get_inline_query_results import GetInlineQueryResults
from .get_installed_sticker_sets import GetInstalledStickerSets
from .get_internal_link_type import GetInternalLinkType
from .get_json_string import GetJsonString
from .get_json_value import GetJsonValue
from .get_language_pack_info import GetLanguagePackInfo
from .get_language_pack_string import GetLanguagePackString
from .get_language_pack_strings import GetLanguagePackStrings
from .get_localization_target_info import GetLocalizationTargetInfo
from .get_log_stream import GetLogStream
from .get_log_tag_verbosity_level import GetLogTagVerbosityLevel
from .get_log_tags import GetLogTags
from .get_log_verbosity_level import GetLogVerbosityLevel
from .get_login_url import GetLoginUrl
from .get_login_url_info import GetLoginUrlInfo
from .get_map_thumbnail_file import GetMapThumbnailFile
from .get_markdown_text import GetMarkdownText
from .get_me import GetMe
from .get_message import GetMessage
from .get_message_embedding_code import GetMessageEmbeddingCode
from .get_message_file_type import GetMessageFileType
from .get_message_import_confirmation_text import GetMessageImportConfirmationText
from .get_message_link import GetMessageLink
from .get_message_link_info import GetMessageLinkInfo
from .get_message_locally import GetMessageLocally
from .get_message_public_forwards import GetMessagePublicForwards
from .get_message_statistics import GetMessageStatistics
from .get_message_thread import GetMessageThread
from .get_message_thread_history import GetMessageThreadHistory
from .get_messages import GetMessages
from .get_network_statistics import GetNetworkStatistics
from .get_option import GetOption
from .get_passport_authorization_form import GetPassportAuthorizationForm
from .get_passport_authorization_form_available_elements import GetPassportAuthorizationFormAvailableElements
from .get_passport_element import GetPassportElement
from .get_password_state import GetPasswordState
from .get_payment_form import GetPaymentForm
from .get_payment_receipt import GetPaymentReceipt
from .get_phone_number_info import GetPhoneNumberInfo
from .get_poll_voters import GetPollVoters
from .get_preferred_country_language import GetPreferredCountryLanguage
from .get_proxies import GetProxies
from .get_proxy_link import GetProxyLink
from .get_push_receiver_id import GetPushReceiverId
from .get_recent_inline_bots import GetRecentInlineBots
from .get_recent_stickers import GetRecentStickers
from .get_recently_visited_t_me_urls import GetRecentlyVisitedTMeUrls
from .get_recommended_chat_filters import GetRecommendedChatFilters
from .get_recovery_email_address import GetRecoveryEmailAddress
from .get_remote_file import GetRemoteFile
from .get_replied_message import GetRepliedMessage
from .get_saved_animations import GetSavedAnimations
from .get_saved_order_info import GetSavedOrderInfo
from .get_scope_notification_settings import GetScopeNotificationSettings
from .get_secret_chat import GetSecretChat
from .get_statistical_graph import GetStatisticalGraph
from .get_sticker_emojis import GetStickerEmojis
from .get_sticker_set import GetStickerSet
from .get_stickers import GetStickers
from .get_storage_statistics import GetStorageStatistics
from .get_storage_statistics_fast import GetStorageStatisticsFast
from .get_suggested_file_name import GetSuggestedFileName
from .get_suggested_sticker_set_name import GetSuggestedStickerSetName
from .get_suitable_discussion_chats import GetSuitableDiscussionChats
from .get_supergroup import GetSupergroup
from .get_supergroup_full_info import GetSupergroupFullInfo
from .get_supergroup_members import GetSupergroupMembers
from .get_support_user import GetSupportUser
from .get_temporary_password_state import GetTemporaryPasswordState
from .get_text_entities import GetTextEntities
from .get_top_chats import GetTopChats
from .get_trending_sticker_sets import GetTrendingStickerSets
from .get_user import GetUser
from .get_user_full_info import GetUserFullInfo
from .get_user_privacy_setting_rules import GetUserPrivacySettingRules
from .get_user_profile_photos import GetUserProfilePhotos
from .get_voice_chat_available_participants import GetVoiceChatAvailableParticipants
from .get_web_page_instant_view import GetWebPageInstantView
from .get_web_page_preview import GetWebPagePreview
from .hide_suggested_action import HideSuggestedAction
from .import_contacts import ImportContacts
from .import_messages import ImportMessages
from .invite_group_call_participants import InviteGroupCallParticipants
from .join_chat import JoinChat
from .join_chat_by_invite_link import JoinChatByInviteLink
from .join_group_call import JoinGroupCall
from .leave_chat import LeaveChat
from .leave_group_call import LeaveGroupCall
from .load_group_call_participants import LoadGroupCallParticipants
from .log_out import LogOut
from .open_chat import OpenChat
from .open_message_content import OpenMessageContent
from .optimize_storage import OptimizeStorage
from .parse_markdown import ParseMarkdown
from .parse_text_entities import ParseTextEntities
from .pin_chat_message import PinChatMessage
from .ping_proxy import PingProxy
from .process_push_notification import ProcessPushNotification
from .read_all_chat_mentions import ReadAllChatMentions
from .read_file_part import ReadFilePart
from .recover_authentication_password import RecoverAuthenticationPassword
from .recover_password import RecoverPassword
from .register_device import RegisterDevice
from .register_user import RegisterUser
from .remove_background import RemoveBackground
from .remove_chat_action_bar import RemoveChatActionBar
from .remove_contacts import RemoveContacts
from .remove_favorite_sticker import RemoveFavoriteSticker
from .remove_notification import RemoveNotification
from .remove_notification_group import RemoveNotificationGroup
from .remove_proxy import RemoveProxy
from .remove_recent_hashtag import RemoveRecentHashtag
from .remove_recent_sticker import RemoveRecentSticker
from .remove_recently_found_chat import RemoveRecentlyFoundChat
from .remove_saved_animation import RemoveSavedAnimation
from .remove_sticker_from_set import RemoveStickerFromSet
from .remove_top_chat import RemoveTopChat
from .reorder_chat_filters import ReorderChatFilters
from .reorder_installed_sticker_sets import ReorderInstalledStickerSets
from .replace_primary_chat_invite_link import ReplacePrimaryChatInviteLink
from .report_chat import ReportChat
from .report_chat_photo import ReportChatPhoto
from .report_supergroup_spam import ReportSupergroupSpam
from .request_authentication_password_recovery import RequestAuthenticationPasswordRecovery
from .request_password_recovery import RequestPasswordRecovery
from .request_qr_code_authentication import RequestQrCodeAuthentication
from .resend_authentication_code import ResendAuthenticationCode
from .resend_change_phone_number_code import ResendChangePhoneNumberCode
from .resend_email_address_verification_code import ResendEmailAddressVerificationCode
from .resend_messages import ResendMessages
from .resend_phone_number_confirmation_code import ResendPhoneNumberConfirmationCode
from .resend_phone_number_verification_code import ResendPhoneNumberVerificationCode
from .resend_recovery_email_address_code import ResendRecoveryEmailAddressCode
from .reset_all_notification_settings import ResetAllNotificationSettings
from .reset_backgrounds import ResetBackgrounds
from .reset_network_statistics import ResetNetworkStatistics
from .reset_password import ResetPassword
from .revoke_chat_invite_link import RevokeChatInviteLink
from .revoke_group_call_invite_link import RevokeGroupCallInviteLink
from .save_application_log_event import SaveApplicationLogEvent
from .search_background import SearchBackground
from .search_call_messages import SearchCallMessages
from .search_chat_members import SearchChatMembers
from .search_chat_messages import SearchChatMessages
from .search_chat_recent_location_messages import SearchChatRecentLocationMessages
from .search_chats import SearchChats
from .search_chats_nearby import SearchChatsNearby
from .search_chats_on_server import SearchChatsOnServer
from .search_contacts import SearchContacts
from .search_emojis import SearchEmojis
from .search_hashtags import SearchHashtags
from .search_installed_sticker_sets import SearchInstalledStickerSets
from .search_messages import SearchMessages
from .search_public_chat import SearchPublicChat
from .search_public_chats import SearchPublicChats
from .search_secret_messages import SearchSecretMessages
from .search_sticker_set import SearchStickerSet
from .search_sticker_sets import SearchStickerSets
from .search_stickers import SearchStickers
from .send_bot_start_message import SendBotStartMessage
from .send_call_debug_information import SendCallDebugInformation
from .send_call_rating import SendCallRating
from .send_call_signaling_data import SendCallSignalingData
from .send_chat_action import SendChatAction
from .send_chat_screenshot_taken_notification import SendChatScreenshotTakenNotification
from .send_custom_request import SendCustomRequest
from .send_email_address_verification_code import SendEmailAddressVerificationCode
from .send_inline_query_result_message import SendInlineQueryResultMessage
from .send_message import SendMessage
from .send_message_album import SendMessageAlbum
from .send_passport_authorization_form import SendPassportAuthorizationForm
from .send_payment_form import SendPaymentForm
from .send_phone_number_confirmation_code import SendPhoneNumberConfirmationCode
from .send_phone_number_verification_code import SendPhoneNumberVerificationCode
from .set_account_ttl import SetAccountTtl
from .set_alarm import SetAlarm
from .set_authentication_phone_number import SetAuthenticationPhoneNumber
from .set_auto_download_settings import SetAutoDownloadSettings
from .set_background import SetBackground
from .set_bio import SetBio
from .set_bot_updates_status import SetBotUpdatesStatus
from .set_chat_client_data import SetChatClientData
from .set_chat_description import SetChatDescription
from .set_chat_discussion_group import SetChatDiscussionGroup
from .set_chat_draft_message import SetChatDraftMessage
from .set_chat_location import SetChatLocation
from .set_chat_member_status import SetChatMemberStatus
from .set_chat_message_ttl_setting import SetChatMessageTtlSetting
from .set_chat_notification_settings import SetChatNotificationSettings
from .set_chat_permissions import SetChatPermissions
from .set_chat_photo import SetChatPhoto
from .set_chat_slow_mode_delay import SetChatSlowModeDelay
from .set_chat_title import SetChatTitle
from .set_commands import SetCommands
from .set_custom_language_pack import SetCustomLanguagePack
from .set_custom_language_pack_string import SetCustomLanguagePackString
from .set_database_encryption_key import SetDatabaseEncryptionKey
from .set_file_generation_progress import SetFileGenerationProgress
from .set_game_score import SetGameScore
from .set_group_call_participant_is_speaking import SetGroupCallParticipantIsSpeaking
from .set_group_call_participant_volume_level import SetGroupCallParticipantVolumeLevel
from .set_group_call_title import SetGroupCallTitle
from .set_inline_game_score import SetInlineGameScore
from .set_location import SetLocation
from .set_log_stream import SetLogStream
from .set_log_tag_verbosity_level import SetLogTagVerbosityLevel
from .set_log_verbosity_level import SetLogVerbosityLevel
from .set_name import SetName
from .set_network_type import SetNetworkType
from .set_option import SetOption
from .set_passport_element import SetPassportElement
from .set_passport_element_errors import SetPassportElementErrors
from .set_password import SetPassword
from .set_pinned_chats import SetPinnedChats
from .set_poll_answer import SetPollAnswer
from .set_profile_photo import SetProfilePhoto
from .set_recovery_email_address import SetRecoveryEmailAddress
from .set_scope_notification_settings import SetScopeNotificationSettings
from .set_sticker_position_in_set import SetStickerPositionInSet
from .set_sticker_set_thumbnail import SetStickerSetThumbnail
from .set_supergroup_sticker_set import SetSupergroupStickerSet
from .set_supergroup_username import SetSupergroupUsername
from .set_tdlib_parameters import SetTdlibParameters
from .set_user_privacy_setting_rules import SetUserPrivacySettingRules
from .set_username import SetUsername
from .set_voice_chat_default_participant import SetVoiceChatDefaultParticipant
from .share_phone_number import SharePhoneNumber
from .start_group_call_recording import StartGroupCallRecording
from .start_group_call_screen_sharing import StartGroupCallScreenSharing
from .start_scheduled_group_call import StartScheduledGroupCall
from .stop_poll import StopPoll
from .synchronize_language_pack import SynchronizeLanguagePack
from .terminate_all_other_sessions import TerminateAllOtherSessions
from .terminate_session import TerminateSession
from .test_call_bytes import TestCallBytes
from .test_call_empty import TestCallEmpty
from .test_call_string import TestCallString
from .test_call_vector_int import TestCallVectorInt
from .test_call_vector_int_object import TestCallVectorIntObject
from .test_call_vector_string import TestCallVectorString
from .test_call_vector_string_object import TestCallVectorStringObject
from .test_get_difference import TestGetDifference
from .test_network import TestNetwork
from .test_proxy import TestProxy
from .test_return_error import TestReturnError
from .test_square_int import TestSquareInt
from .test_use_update import TestUseUpdate
from .toggle_chat_default_disable_notification import ToggleChatDefaultDisableNotification
from .toggle_chat_is_marked_as_unread import ToggleChatIsMarkedAsUnread
from .toggle_chat_is_pinned import ToggleChatIsPinned
from .toggle_group_call_enabled_start_notification import ToggleGroupCallEnabledStartNotification
from .toggle_group_call_is_my_video_enabled import ToggleGroupCallIsMyVideoEnabled
from .toggle_group_call_is_my_video_paused import ToggleGroupCallIsMyVideoPaused
from .toggle_group_call_mute_new_participants import ToggleGroupCallMuteNewParticipants
from .toggle_group_call_participant_is_hand_raised import ToggleGroupCallParticipantIsHandRaised
from .toggle_group_call_participant_is_muted import ToggleGroupCallParticipantIsMuted
from .toggle_group_call_screen_sharing_is_paused import ToggleGroupCallScreenSharingIsPaused
from .toggle_message_sender_is_blocked import ToggleMessageSenderIsBlocked
from .toggle_supergroup_is_all_history_available import ToggleSupergroupIsAllHistoryAvailable
from .toggle_supergroup_is_broadcast_group import ToggleSupergroupIsBroadcastGroup
from .toggle_supergroup_sign_messages import ToggleSupergroupSignMessages
from .transfer_chat_ownership import TransferChatOwnership
from .unpin_all_chat_messages import UnpinAllChatMessages
from .unpin_chat_message import UnpinChatMessage
from .upgrade_basic_group_chat_to_supergroup_chat import UpgradeBasicGroupChatToSupergroupChat
from .upload_file import UploadFile
from .upload_sticker_file import UploadStickerFile
from .validate_order_info import ValidateOrderInfo
from .view_messages import ViewMessages
from .view_trending_sticker_sets import ViewTrendingStickerSets
from .write_generated_file_part import WriteGeneratedFilePart

__all__ = [
    "AcceptCall",
    "AcceptTermsOfService",
    "AddChatMember",
    "AddChatMembers",
    "AddChatToList",
    "AddContact",
    "AddCustomServerLanguagePack",
    "AddFavoriteSticker",
    "AddLocalMessage",
    "AddLogMessage",
    "AddNetworkStatistics",
    "AddProxy",
    "AddRecentSticker",
    "AddRecentlyFoundChat",
    "AddSavedAnimation",
    "AddStickerToSet",
    "AnswerCallbackQuery",
    "AnswerCustomQuery",
    "AnswerInlineQuery",
    "AnswerPreCheckoutQuery",
    "AnswerShippingQuery",
    "BanChatMember",
    "BlockMessageSenderFromReplies",
    "CanTransferOwnership",
    "CancelDownloadFile",
    "CancelPasswordReset",
    "CancelUploadFile",
    "ChangeImportedContacts",
    "ChangePhoneNumber",
    "ChangeStickerSet",
    "CheckAuthenticationBotToken",
    "CheckAuthenticationCode",
    "CheckAuthenticationPassword",
    "CheckAuthenticationPasswordRecoveryCode",
    "CheckChangePhoneNumberCode",
    "CheckChatInviteLink",
    "CheckChatUsername",
    "CheckCreatedPublicChatsLimit",
    "CheckDatabaseEncryptionKey",
    "CheckEmailAddressVerificationCode",
    "CheckPasswordRecoveryCode",
    "CheckPhoneNumberConfirmationCode",
    "CheckPhoneNumberVerificationCode",
    "CheckRecoveryEmailAddressCode",
    "CheckStickerSetName",
    "CleanFileName",
    "ClearAllDraftMessages",
    "ClearImportedContacts",
    "ClearRecentStickers",
    "ClearRecentlyFoundChats",
    "Close",
    "CloseChat",
    "CloseSecretChat",
    "ConfirmQrCodeAuthentication",
    "CreateBasicGroupChat",
    "CreateCall",
    "CreateChatFilter",
    "CreateChatInviteLink",
    "CreateNewBasicGroupChat",
    "CreateNewSecretChat",
    "CreateNewStickerSet",
    "CreateNewSupergroupChat",
    "CreatePrivateChat",
    "CreateSecretChat",
    "CreateSupergroupChat",
    "CreateTemporaryPassword",
    "CreateVoiceChat",
    "DeleteAccount",
    "DeleteAllCallMessages",
    "DeleteAllRevokedChatInviteLinks",
    "DeleteChat",
    "DeleteChatFilter",
    "DeleteChatHistory",
    "DeleteChatMessagesFromUser",
    "DeleteChatReplyMarkup",
    "DeleteCommands",
    "DeleteFile",
    "DeleteLanguagePack",
    "DeleteMessages",
    "DeletePassportElement",
    "DeleteProfilePhoto",
    "DeleteRevokedChatInviteLink",
    "DeleteSavedCredentials",
    "DeleteSavedOrderInfo",
    "Destroy",
    "DisableProxy",
    "DiscardCall",
    "DiscardGroupCall",
    "DisconnectAllWebsites",
    "DisconnectWebsite",
    "DownloadFile",
    "EditChatFilter",
    "EditChatInviteLink",
    "EditCustomLanguagePackInfo",
    "EditInlineMessageCaption",
    "EditInlineMessageLiveLocation",
    "EditInlineMessageMedia",
    "EditInlineMessageReplyMarkup",
    "EditInlineMessageText",
    "EditMessageCaption",
    "EditMessageLiveLocation",
    "EditMessageMedia",
    "EditMessageReplyMarkup",
    "EditMessageSchedulingState",
    "EditMessageText",
    "EditProxy",
    "EnableProxy",
    "EndGroupCallRecording",
    "EndGroupCallScreenSharing",
    "FinishFileGeneration",
    "ForwardMessages",
    "GetAccountTtl",
    "GetActiveLiveLocationMessages",
    "GetActiveSessions",
    "GetAllPassportElements",
    "GetApplicationConfig",
    "GetApplicationDownloadLink",
    "GetArchivedStickerSets",
    "GetAttachedStickerSets",
    "GetAuthorizationState",
    "GetAutoDownloadSettingsPresets",
    "GetBackgroundUrl",
    "GetBackgrounds",
    "GetBankCardInfo",
    "GetBasicGroup",
    "GetBasicGroupFullInfo",
    "GetBlockedMessageSenders",
    "GetCallbackQueryAnswer",
    "GetCallbackQueryMessage",
    "GetChat",
    "GetChatAdministrators",
    "GetChatEventLog",
    "GetChatFilter",
    "GetChatFilterDefaultIconName",
    "GetChatHistory",
    "GetChatInviteLink",
    "GetChatInviteLinkCounts",
    "GetChatInviteLinkMembers",
    "GetChatInviteLinks",
    "GetChatListsToAddChat",
    "GetChatMember",
    "GetChatMessageByDate",
    "GetChatMessageCount",
    "GetChatNotificationSettingsExceptions",
    "GetChatPinnedMessage",
    "GetChatScheduledMessages",
    "GetChatStatistics",
    "GetChatStatisticsUrl",
    "GetChats",
    "GetCommands",
    "GetConnectedWebsites",
    "GetContacts",
    "GetCountries",
    "GetCountryCode",
    "GetCreatedPublicChats",
    "GetCurrentState",
    "GetDatabaseStatistics",
    "GetDeepLinkInfo",
    "GetEmojiSuggestionsUrl",
    "GetExternalLink",
    "GetExternalLinkInfo",
    "GetFavoriteStickers",
    "GetFile",
    "GetFileDownloadedPrefixSize",
    "GetFileExtension",
    "GetFileMimeType",
    "GetGameHighScores",
    "GetGroupCall",
    "GetGroupCallInviteLink",
    "GetGroupCallStreamSegment",
    "GetGroupsInCommon",
    "GetImportedContactCount",
    "GetInactiveSupergroupChats",
    "GetInlineGameHighScores",
    "GetInlineQueryResults",
    "GetInstalledStickerSets",
    "GetInternalLinkType",
    "GetJsonString",
    "GetJsonValue",
    "GetLanguagePackInfo",
    "GetLanguagePackString",
    "GetLanguagePackStrings",
    "GetLocalizationTargetInfo",
    "GetLogStream",
    "GetLogTagVerbosityLevel",
    "GetLogTags",
    "GetLogVerbosityLevel",
    "GetLoginUrl",
    "GetLoginUrlInfo",
    "GetMapThumbnailFile",
    "GetMarkdownText",
    "GetMe",
    "GetMessage",
    "GetMessageEmbeddingCode",
    "GetMessageFileType",
    "GetMessageImportConfirmationText",
    "GetMessageLink",
    "GetMessageLinkInfo",
    "GetMessageLocally",
    "GetMessagePublicForwards",
    "GetMessageStatistics",
    "GetMessageThread",
    "GetMessageThreadHistory",
    "GetMessages",
    "GetNetworkStatistics",
    "GetOption",
    "GetPassportAuthorizationForm",
    "GetPassportAuthorizationFormAvailableElements",
    "GetPassportElement",
    "GetPasswordState",
    "GetPaymentForm",
    "GetPaymentReceipt",
    "GetPhoneNumberInfo",
    "GetPollVoters",
    "GetPreferredCountryLanguage",
    "GetProxies",
    "GetProxyLink",
    "GetPushReceiverId",
    "GetRecentInlineBots",
    "GetRecentStickers",
    "GetRecentlyVisitedTMeUrls",
    "GetRecommendedChatFilters",
    "GetRecoveryEmailAddress",
    "GetRemoteFile",
    "GetRepliedMessage",
    "GetSavedAnimations",
    "GetSavedOrderInfo",
    "GetScopeNotificationSettings",
    "GetSecretChat",
    "GetStatisticalGraph",
    "GetStickerEmojis",
    "GetStickerSet",
    "GetStickers",
    "GetStorageStatistics",
    "GetStorageStatisticsFast",
    "GetSuggestedFileName",
    "GetSuggestedStickerSetName",
    "GetSuitableDiscussionChats",
    "GetSupergroup",
    "GetSupergroupFullInfo",
    "GetSupergroupMembers",
    "GetSupportUser",
    "GetTemporaryPasswordState",
    "GetTextEntities",
    "GetTopChats",
    "GetTrendingStickerSets",
    "GetUser",
    "GetUserFullInfo",
    "GetUserPrivacySettingRules",
    "GetUserProfilePhotos",
    "GetVoiceChatAvailableParticipants",
    "GetWebPageInstantView",
    "GetWebPagePreview",
    "HideSuggestedAction",
    "ImportContacts",
    "ImportMessages",
    "InviteGroupCallParticipants",
    "JoinChat",
    "JoinChatByInviteLink",
    "JoinGroupCall",
    "LeaveChat",
    "LeaveGroupCall",
    "LoadGroupCallParticipants",
    "LogOut",
    "OpenChat",
    "OpenMessageContent",
    "OptimizeStorage",
    "ParseMarkdown",
    "ParseTextEntities",
    "PinChatMessage",
    "PingProxy",
    "ProcessPushNotification",
    "ReadAllChatMentions",
    "ReadFilePart",
    "RecoverAuthenticationPassword",
    "RecoverPassword",
    "RegisterDevice",
    "RegisterUser",
    "RemoveBackground",
    "RemoveChatActionBar",
    "RemoveContacts",
    "RemoveFavoriteSticker",
    "RemoveNotification",
    "RemoveNotificationGroup",
    "RemoveProxy",
    "RemoveRecentHashtag",
    "RemoveRecentSticker",
    "RemoveRecentlyFoundChat",
    "RemoveSavedAnimation",
    "RemoveStickerFromSet",
    "RemoveTopChat",
    "ReorderChatFilters",
    "ReorderInstalledStickerSets",
    "ReplacePrimaryChatInviteLink",
    "ReportChat",
    "ReportChatPhoto",
    "ReportSupergroupSpam",
    "RequestAuthenticationPasswordRecovery",
    "RequestPasswordRecovery",
    "RequestQrCodeAuthentication",
    "ResendAuthenticationCode",
    "ResendChangePhoneNumberCode",
    "ResendEmailAddressVerificationCode",
    "ResendMessages",
    "ResendPhoneNumberConfirmationCode",
    "ResendPhoneNumberVerificationCode",
    "ResendRecoveryEmailAddressCode",
    "ResetAllNotificationSettings",
    "ResetBackgrounds",
    "ResetNetworkStatistics",
    "ResetPassword",
    "RevokeChatInviteLink",
    "RevokeGroupCallInviteLink",
    "SaveApplicationLogEvent",
    "SearchBackground",
    "SearchCallMessages",
    "SearchChatMembers",
    "SearchChatMessages",
    "SearchChatRecentLocationMessages",
    "SearchChats",
    "SearchChatsNearby",
    "SearchChatsOnServer",
    "SearchContacts",
    "SearchEmojis",
    "SearchHashtags",
    "SearchInstalledStickerSets",
    "SearchMessages",
    "SearchPublicChat",
    "SearchPublicChats",
    "SearchSecretMessages",
    "SearchStickerSet",
    "SearchStickerSets",
    "SearchStickers",
    "SendBotStartMessage",
    "SendCallDebugInformation",
    "SendCallRating",
    "SendCallSignalingData",
    "SendChatAction",
    "SendChatScreenshotTakenNotification",
    "SendCustomRequest",
    "SendEmailAddressVerificationCode",
    "SendInlineQueryResultMessage",
    "SendMessage",
    "SendMessageAlbum",
    "SendPassportAuthorizationForm",
    "SendPaymentForm",
    "SendPhoneNumberConfirmationCode",
    "SendPhoneNumberVerificationCode",
    "SetAccountTtl",
    "SetAlarm",
    "SetAuthenticationPhoneNumber",
    "SetAutoDownloadSettings",
    "SetBackground",
    "SetBio",
    "SetBotUpdatesStatus",
    "SetChatClientData",
    "SetChatDescription",
    "SetChatDiscussionGroup",
    "SetChatDraftMessage",
    "SetChatLocation",
    "SetChatMemberStatus",
    "SetChatMessageTtlSetting",
    "SetChatNotificationSettings",
    "SetChatPermissions",
    "SetChatPhoto",
    "SetChatSlowModeDelay",
    "SetChatTitle",
    "SetCommands",
    "SetCustomLanguagePack",
    "SetCustomLanguagePackString",
    "SetDatabaseEncryptionKey",
    "SetFileGenerationProgress",
    "SetGameScore",
    "SetGroupCallParticipantIsSpeaking",
    "SetGroupCallParticipantVolumeLevel",
    "SetGroupCallTitle",
    "SetInlineGameScore",
    "SetLocation",
    "SetLogStream",
    "SetLogTagVerbosityLevel",
    "SetLogVerbosityLevel",
    "SetName",
    "SetNetworkType",
    "SetOption",
    "SetPassportElement",
    "SetPassportElementErrors",
    "SetPassword",
    "SetPinnedChats",
    "SetPollAnswer",
    "SetProfilePhoto",
    "SetRecoveryEmailAddress",
    "SetScopeNotificationSettings",
    "SetStickerPositionInSet",
    "SetStickerSetThumbnail",
    "SetSupergroupStickerSet",
    "SetSupergroupUsername",
    "SetTdlibParameters",
    "SetUserPrivacySettingRules",
    "SetUsername",
    "SetVoiceChatDefaultParticipant",
    "SharePhoneNumber",
    "StartGroupCallRecording",
    "StartGroupCallScreenSharing",
    "StartScheduledGroupCall",
    "StopPoll",
    "SynchronizeLanguagePack",
    "TerminateAllOtherSessions",
    "TerminateSession",
    "TestCallBytes",
    "TestCallEmpty",
    "TestCallString",
    "TestCallVectorInt",
    "TestCallVectorIntObject",
    "TestCallVectorString",
    "TestCallVectorStringObject",
    "TestGetDifference",
    "TestNetwork",
    "TestProxy",
    "TestReturnError",
    "TestSquareInt",
    "TestUseUpdate",
    "ToggleChatDefaultDisableNotification",
    "ToggleChatIsMarkedAsUnread",
    "ToggleChatIsPinned",
    "ToggleGroupCallEnabledStartNotification",
    "ToggleGroupCallIsMyVideoEnabled",
    "ToggleGroupCallIsMyVideoPaused",
    "ToggleGroupCallMuteNewParticipants",
    "ToggleGroupCallParticipantIsHandRaised",
    "ToggleGroupCallParticipantIsMuted",
    "ToggleGroupCallScreenSharingIsPaused",
    "ToggleMessageSenderIsBlocked",
    "ToggleSupergroupIsAllHistoryAvailable",
    "ToggleSupergroupIsBroadcastGroup",
    "ToggleSupergroupSignMessages",
    "TransferChatOwnership",
    "UnpinAllChatMessages",
    "UnpinChatMessage",
    "UpgradeBasicGroupChatToSupergroupChat",
    "UploadFile",
    "UploadStickerFile",
    "ValidateOrderInfo",
    "ViewMessages",
    "ViewTrendingStickerSets",
    "WriteGeneratedFilePart",
]



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetSupergroupUsername(BaseObject):
    """
    Changes the username of a supergroup or channel, requires owner privileges in the supergroup or channel
    
    Params:
        supergroup_id (:class:`int`)
            Identifier of the supergroup or channel
        
        username (:class:`str`)
            New value of the username. Use an empty string to remove the username
        
    """

    ID: str = Field("setSupergroupUsername", alias="@type")
    supergroup_id: int
    username: str

    @staticmethod
    def read(q: dict) -> SetSupergroupUsername:
        return SetSupergroupUsername.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import MessageSender


class BanChatMember(BaseObject):
    """
    Bans a member in a chat. Members can't be banned in private or secret chats. In supergroups and channels, the user will not be able to return to the group on their own using invite links, etc., unless unbanned first
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        member_id (:class:`MessageSender`)
            Member identifier
        
        banned_until_date (:class:`int`)
            Point in time (Unix timestamp) when the user will be unbanned; 0 if never. If the user is banned for more than 366 days or for less than 30 seconds from the current time, the user is considered to be banned forever. Ignored in basic groups
        
        revoke_messages (:class:`bool`)
            Pass true to delete all messages in the chat for the user. Always true for supergroups and channels
        
    """

    ID: str = Field("banChatMember", alias="@type")
    chat_id: int
    member_id: MessageSender
    banned_until_date: int
    revoke_messages: bool

    @staticmethod
    def read(q: dict) -> BanChatMember:
        return BanChatMember.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class InputCredentials(BaseObject):
    """
    Contains information about the payment method chosen by the user
    
    """

    ID: str = Field("inputCredentials", alias="@type")


class InputCredentialsApplePay(InputCredentials):
    """
    Applies if a user enters new credentials using Apple Pay
    
    Params:
        data (:class:`str`)
            JSON-encoded data with the credential identifier
        
    """

    ID: str = Field("inputCredentialsApplePay", alias="@type")
    data: str

    @staticmethod
    def read(q: dict) -> InputCredentialsApplePay:
        return InputCredentialsApplePay.construct(**q)


class InputCredentialsGooglePay(InputCredentials):
    """
    Applies if a user enters new credentials using Google Pay
    
    Params:
        data (:class:`str`)
            JSON-encoded data with the credential identifier
        
    """

    ID: str = Field("inputCredentialsGooglePay", alias="@type")
    data: str

    @staticmethod
    def read(q: dict) -> InputCredentialsGooglePay:
        return InputCredentialsGooglePay.construct(**q)


class InputCredentialsNew(InputCredentials):
    """
    Applies if a user enters new credentials on a payment provider website
    
    Params:
        data (:class:`str`)
            Contains JSON-encoded data with a credential identifier from the payment provider
        
        allow_save (:class:`bool`)
            True, if the credential identifier can be saved on the server side
        
    """

    ID: str = Field("inputCredentialsNew", alias="@type")
    data: str
    allow_save: bool

    @staticmethod
    def read(q: dict) -> InputCredentialsNew:
        return InputCredentialsNew.construct(**q)


class InputCredentialsSaved(InputCredentials):
    """
    Applies if a user chooses some previously saved payment credentials. To use their previously saved credentials, the user must have a valid temporary password
    
    Params:
        saved_credentials_id (:class:`str`)
            Identifier of the saved credentials
        
    """

    ID: str = Field("inputCredentialsSaved", alias="@type")
    saved_credentials_id: str

    @staticmethod
    def read(q: dict) -> InputCredentialsSaved:
        return InputCredentialsSaved.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputFile


class RemoveSavedAnimation(BaseObject):
    """
    Removes an animation from the list of saved animations
    
    Params:
        animation (:class:`InputFile`)
            Animation file to be removed
        
    """

    ID: str = Field("removeSavedAnimation", alias="@type")
    animation: InputFile

    @staticmethod
    def read(q: dict) -> RemoveSavedAnimation:
        return RemoveSavedAnimation.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import PassportElementType


class SendPassportAuthorizationForm(BaseObject):
    """
    Sends a Telegram Passport authorization form, effectively sharing data with the service. This method must be called after getPassportAuthorizationFormAvailableElements if some previously available elements are going to be reused
    
    Params:
        autorization_form_id (:class:`int`)
            Authorization form identifier
        
        types (:obj:`list[PassportElementType]`)
            Types of Telegram Passport elements chosen by user to complete the authorization form
        
    """

    ID: str = Field("sendPassportAuthorizationForm", alias="@type")
    autorization_form_id: int
    types: list[PassportElementType]

    @staticmethod
    def read(q: dict) -> SendPassportAuthorizationForm:
        return SendPassportAuthorizationForm.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .contact import Contact
from .input_message_content import InputMessageContent
from .location import Location
from .reply_markup import ReplyMarkup
from .venue import Venue
from ..base_object import BaseObject


class InputInlineQueryResult(BaseObject):
    """
    Represents a single result of an inline query; for bots only
    
    """

    ID: str = Field("inputInlineQueryResult", alias="@type")


class InputInlineQueryResultAnimation(InputInlineQueryResult):
    """
    Represents a link to an animated GIF or an animated (i.e. without sound) H.264/MPEG-4 AVC video
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        title (:class:`str`)
            Title of the query result
        
        thumbnail_url (:class:`str`)
            URL of the result thumbnail (JPEG, GIF, or MPEG4), if it exists
        
        thumbnail_mime_type (:class:`str`)
            MIME type of the video thumbnail. If non-empty, must be one of "image/jpeg", "image/gif" and "video/mp4"
        
        video_url (:class:`str`)
            The URL of the video file (file size must not exceed 1MB)
        
        video_mime_type (:class:`str`)
            MIME type of the video file. Must be one of "image/gif" and "video/mp4"
        
        video_duration (:class:`int`)
            Duration of the video, in seconds
        
        video_width (:class:`int`)
            Width of the video
        
        video_height (:class:`int`)
            Height of the video
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageAnimation, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultAnimation", alias="@type")
    id: str
    title: str
    thumbnail_url: str
    thumbnail_mime_type: str
    video_url: str
    video_mime_type: str
    video_duration: int
    video_width: int
    video_height: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultAnimation:
        return InputInlineQueryResultAnimation.construct(**q)


class InputInlineQueryResultArticle(InputInlineQueryResult):
    """
    Represents a link to an article or web page
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        url (:class:`str`)
            URL of the result, if it exists
        
        hide_url (:class:`bool`)
            True, if the URL must be not shown
        
        title (:class:`str`)
            Title of the result
        
        param_description (:class:`str`)
            A short description of the result
        
        thumbnail_url (:class:`str`)
            URL of the result thumbnail, if it exists
        
        thumbnail_width (:class:`int`)
            Thumbnail width, if known
        
        thumbnail_height (:class:`int`)
            Thumbnail height, if known
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultArticle", alias="@type")
    id: str
    url: str
    hide_url: bool
    title: str
    param_description: str
    thumbnail_url: str
    thumbnail_width: int
    thumbnail_height: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultArticle:
        return InputInlineQueryResultArticle.construct(**q)


class InputInlineQueryResultAudio(InputInlineQueryResult):
    """
    Represents a link to an MP3 audio file
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        title (:class:`str`)
            Title of the audio file
        
        performer (:class:`str`)
            Performer of the audio file
        
        audio_url (:class:`str`)
            The URL of the audio file
        
        audio_duration (:class:`int`)
            Audio file duration, in seconds
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageAudio, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultAudio", alias="@type")
    id: str
    title: str
    performer: str
    audio_url: str
    audio_duration: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultAudio:
        return InputInlineQueryResultAudio.construct(**q)


class InputInlineQueryResultContact(InputInlineQueryResult):
    """
    Represents a user contact
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        contact (:class:`Contact`)
            User contact
        
        thumbnail_url (:class:`str`)
            URL of the result thumbnail, if it exists
        
        thumbnail_width (:class:`int`)
            Thumbnail width, if known
        
        thumbnail_height (:class:`int`)
            Thumbnail height, if known
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultContact", alias="@type")
    id: str
    contact: Contact
    thumbnail_url: str
    thumbnail_width: int
    thumbnail_height: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultContact:
        return InputInlineQueryResultContact.construct(**q)


class InputInlineQueryResultDocument(InputInlineQueryResult):
    """
    Represents a link to a file
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        title (:class:`str`)
            Title of the resulting file
        
        param_description (:class:`str`)
            Short description of the result, if known
        
        document_url (:class:`str`)
            URL of the file
        
        mime_type (:class:`str`)
            MIME type of the file content; only "application/pdf" and "application/zip" are currently allowed
        
        thumbnail_url (:class:`str`)
            The URL of the file thumbnail, if it exists
        
        thumbnail_width (:class:`int`)
            Width of the thumbnail
        
        thumbnail_height (:class:`int`)
            Height of the thumbnail
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageDocument, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultDocument", alias="@type")
    id: str
    title: str
    param_description: str
    document_url: str
    mime_type: str
    thumbnail_url: str
    thumbnail_width: int
    thumbnail_height: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultDocument:
        return InputInlineQueryResultDocument.construct(**q)


class InputInlineQueryResultGame(InputInlineQueryResult):
    """
    Represents a game
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        game_short_name (:class:`str`)
            Short name of the game
        
        reply_markup (:class:`ReplyMarkup`)
            Message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
    """

    ID: str = Field("inputInlineQueryResultGame", alias="@type")
    id: str
    game_short_name: str
    reply_markup: ReplyMarkup

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultGame:
        return InputInlineQueryResultGame.construct(**q)


class InputInlineQueryResultLocation(InputInlineQueryResult):
    """
    Represents a point on the map
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        location (:class:`Location`)
            Location result
        
        live_period (:class:`int`)
            Amount of time relative to the message sent time until the location can be updated, in seconds
        
        title (:class:`str`)
            Title of the result
        
        thumbnail_url (:class:`str`)
            URL of the result thumbnail, if it exists
        
        thumbnail_width (:class:`int`)
            Thumbnail width, if known
        
        thumbnail_height (:class:`int`)
            Thumbnail height, if known
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultLocation", alias="@type")
    id: str
    location: Location
    live_period: int
    title: str
    thumbnail_url: str
    thumbnail_width: int
    thumbnail_height: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultLocation:
        return InputInlineQueryResultLocation.construct(**q)


class InputInlineQueryResultPhoto(InputInlineQueryResult):
    """
    Represents link to a JPEG image
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        title (:class:`str`)
            Title of the result, if known
        
        param_description (:class:`str`)
            A short description of the result, if known
        
        thumbnail_url (:class:`str`)
            URL of the photo thumbnail, if it exists
        
        photo_url (:class:`str`)
            The URL of the JPEG photo (photo size must not exceed 5MB)
        
        photo_width (:class:`int`)
            Width of the photo
        
        photo_height (:class:`int`)
            Height of the photo
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessagePhoto, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultPhoto", alias="@type")
    id: str
    title: str
    param_description: str
    thumbnail_url: str
    photo_url: str
    photo_width: int
    photo_height: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultPhoto:
        return InputInlineQueryResultPhoto.construct(**q)


class InputInlineQueryResultSticker(InputInlineQueryResult):
    """
    Represents a link to a WEBP or TGS sticker
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        thumbnail_url (:class:`str`)
            URL of the sticker thumbnail, if it exists
        
        sticker_url (:class:`str`)
            The URL of the WEBP or TGS sticker (sticker file size must not exceed 5MB)
        
        sticker_width (:class:`int`)
            Width of the sticker
        
        sticker_height (:class:`int`)
            Height of the sticker
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageSticker, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultSticker", alias="@type")
    id: str
    thumbnail_url: str
    sticker_url: str
    sticker_width: int
    sticker_height: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultSticker:
        return InputInlineQueryResultSticker.construct(**q)


class InputInlineQueryResultVenue(InputInlineQueryResult):
    """
    Represents information about a venue
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        venue (:class:`Venue`)
            Venue result
        
        thumbnail_url (:class:`str`)
            URL of the result thumbnail, if it exists
        
        thumbnail_width (:class:`int`)
            Thumbnail width, if known
        
        thumbnail_height (:class:`int`)
            Thumbnail height, if known
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultVenue", alias="@type")
    id: str
    venue: Venue
    thumbnail_url: str
    thumbnail_width: int
    thumbnail_height: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultVenue:
        return InputInlineQueryResultVenue.construct(**q)


class InputInlineQueryResultVideo(InputInlineQueryResult):
    """
    Represents a link to a page containing an embedded video player or a video file
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        title (:class:`str`)
            Title of the result
        
        param_description (:class:`str`)
            A short description of the result, if known
        
        thumbnail_url (:class:`str`)
            The URL of the video thumbnail (JPEG), if it exists
        
        video_url (:class:`str`)
            URL of the embedded video player or video file
        
        mime_type (:class:`str`)
            MIME type of the content of the video URL, only "text/html" or "video/mp4" are currently supported
        
        video_width (:class:`int`)
            Width of the video
        
        video_height (:class:`int`)
            Height of the video
        
        video_duration (:class:`int`)
            Video duration, in seconds
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageVideo, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultVideo", alias="@type")
    id: str
    title: str
    param_description: str
    thumbnail_url: str
    video_url: str
    mime_type: str
    video_width: int
    video_height: int
    video_duration: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultVideo:
        return InputInlineQueryResultVideo.construct(**q)


class InputInlineQueryResultVoiceNote(InputInlineQueryResult):
    """
    Represents a link to an opus-encoded audio file within an OGG container, single channel audio
    
    Params:
        id (:class:`str`)
            Unique identifier of the query result
        
        title (:class:`str`)
            Title of the voice note
        
        voice_note_url (:class:`str`)
            The URL of the voice note file
        
        voice_note_duration (:class:`int`)
            Duration of the voice note, in seconds
        
        reply_markup (:class:`ReplyMarkup`)
            The message reply markup. Must be of type replyMarkupInlineKeyboard or null
        
        input_message_content (:class:`InputMessageContent`)
            The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageVoiceNote, inputMessageInvoice, inputMessageLocation, inputMessageVenue or inputMessageContact
        
    """

    ID: str = Field("inputInlineQueryResultVoiceNote", alias="@type")
    id: str
    title: str
    voice_note_url: str
    voice_note_duration: int
    reply_markup: ReplyMarkup
    input_message_content: InputMessageContent

    @staticmethod
    def read(q: dict) -> InputInlineQueryResultVoiceNote:
        return InputInlineQueryResultVoiceNote.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import BotCommandScope


class DeleteCommands(BaseObject):
    """
    Deletes commands supported by the bot for the given user scope and language; for bots only
    
    Params:
        scope (:class:`BotCommandScope`)
            The scope to which the commands are relevant
        
        language_code (:class:`str`)
            A two-letter ISO 639-1 country code or an empty string
        
    """

    ID: str = Field("deleteCommands", alias="@type")
    scope: BotCommandScope
    language_code: str

    @staticmethod
    def read(q: dict) -> DeleteCommands:
        return DeleteCommands.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ReplacePrimaryChatInviteLink(BaseObject):
    """
    Replaces current primary invite link for a chat with a new primary invite link. Available for basic groups, supergroups, and channels. Requires administrator privileges and can_invite_users right
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
    """

    ID: str = Field("replacePrimaryChatInviteLink", alias="@type")
    chat_id: int

    @staticmethod
    def read(q: dict) -> ReplacePrimaryChatInviteLink:
        return ReplacePrimaryChatInviteLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .rich_text import RichText
from ..base_object import BaseObject


class PageBlockCaption(BaseObject):
    """
    Contains a caption of an instant view web page block, consisting of a text and a trailing credit
    
    Params:
        text (:class:`RichText`)
            Content of the caption
        
        credit (:class:`RichText`)
            Block credit (like HTML tag <cite>)
        
    """

    ID: str = Field("pageBlockCaption", alias="@type")
    text: RichText
    credit: RichText

    @staticmethod
    def read(q: dict) -> PageBlockCaption:
        return PageBlockCaption.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .file_type import FileType
from ..base_object import BaseObject


class StorageStatisticsByFileType(BaseObject):
    """
    Contains the storage usage statistics for a specific file type
    
    Params:
        file_type (:class:`FileType`)
            File type
        
        size (:class:`int`)
            Total size of the files
        
        count (:class:`int`)
            Total number of files
        
    """

    ID: str = Field("storageStatisticsByFileType", alias="@type")
    file_type: FileType
    size: int
    count: int

    @staticmethod
    def read(q: dict) -> StorageStatisticsByFileType:
        return StorageStatisticsByFileType.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetAlarm(BaseObject):
    """
    Succeeds after a specified amount of time has passed. Can be called before initialization
    
    Params:
        seconds (:class:`float`)
            Number of seconds before the function returns
        
    """

    ID: str = Field("setAlarm", alias="@type")
    seconds: float

    @staticmethod
    def read(q: dict) -> SetAlarm:
        return SetAlarm.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckAuthenticationPassword(BaseObject):
    """
    Checks the authentication password for correctness. Works only when the current authorization state is authorizationStateWaitPassword
    
    Params:
        password (:class:`str`)
            The password to check
        
    """

    ID: str = Field("checkAuthenticationPassword", alias="@type")
    password: str

    @staticmethod
    def read(q: dict) -> CheckAuthenticationPassword:
        return CheckAuthenticationPassword.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .dated_file import DatedFile
from .passport_element_type import PassportElementType
from ..base_object import BaseObject


class EncryptedPassportElement(BaseObject):
    """
    Contains information about an encrypted Telegram Passport element; for bots only
    
    Params:
        type_ (:class:`PassportElementType`)
            Type of Telegram Passport element
        
        data (:class:`str`)
            Encrypted JSON-encoded data about the user
        
        front_side (:class:`DatedFile`)
            The front side of an identity document
        
        reverse_side (:class:`DatedFile`)
            The reverse side of an identity document; may be null
        
        selfie (:class:`DatedFile`)
            Selfie with the document; may be null
        
        translation (:obj:`list[DatedFile]`)
            List of files containing a certified English translation of the document
        
        files (:obj:`list[DatedFile]`)
            List of attached files
        
        value (:class:`str`)
            Unencrypted data, phone number or email address
        
        hash_ (:class:`str`)
            Hash of the entire element
        
    """

    ID: str = Field("encryptedPassportElement", alias="@type")
    type_: PassportElementType = Field(..., alias='type')
    data: str
    front_side: DatedFile
    reverse_side: typing.Optional[DatedFile] = None
    selfie: typing.Optional[DatedFile] = None
    translation: list[DatedFile]
    files: list[DatedFile]
    value: str
    hash_: str = Field(..., alias='hash')

    @staticmethod
    def read(q: dict) -> EncryptedPassportElement:
        return EncryptedPassportElement.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class LogStream(BaseObject):
    """
    Describes a stream to which TDLib internal log is written
    
    """

    ID: str = Field("logStream", alias="@type")


class LogStreamDefault(LogStream):
    """
    The log is written to stderr or an OS specific log
    
    """

    ID: str = Field("logStreamDefault", alias="@type")

    @staticmethod
    def read(q: dict) -> LogStreamDefault:
        return LogStreamDefault.construct(**q)


class LogStreamEmpty(LogStream):
    """
    The log is written nowhere
    
    """

    ID: str = Field("logStreamEmpty", alias="@type")

    @staticmethod
    def read(q: dict) -> LogStreamEmpty:
        return LogStreamEmpty.construct(**q)


class LogStreamFile(LogStream):
    """
    The log is written to a file
    
    Params:
        path (:class:`str`)
            Path to the file to where the internal TDLib log will be written
        
        max_file_size (:class:`int`)
            The maximum size of the file to where the internal TDLib log is written before the file will be auto-rotated
        
        redirect_stderr (:class:`bool`)
            Pass true to additionally redirect stderr to the log file. Ignored on Windows
        
    """

    ID: str = Field("logStreamFile", alias="@type")
    path: str
    max_file_size: int
    redirect_stderr: bool

    @staticmethod
    def read(q: dict) -> LogStreamFile:
        return LogStreamFile.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import SuggestedAction


class HideSuggestedAction(BaseObject):
    """
    Hides a suggested action
    
    Params:
        action (:class:`SuggestedAction`)
            Suggested action to hide
        
    """

    ID: str = Field("hideSuggestedAction", alias="@type")
    action: SuggestedAction

    @staticmethod
    def read(q: dict) -> HideSuggestedAction:
        return HideSuggestedAction.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class HttpUrl(BaseObject):
    """
    Contains an HTTP URL
    
    Params:
        url (:class:`str`)
            The URL
        
    """

    ID: str = Field("httpUrl", alias="@type")
    url: str

    @staticmethod
    def read(q: dict) -> HttpUrl:
        return HttpUrl.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class EnableProxy(BaseObject):
    """
    Enables a proxy. Only one proxy can be enabled at a time. Can be called before authorization
    
    Params:
        proxy_id (:class:`int`)
            Proxy identifier
        
    """

    ID: str = Field("enableProxy", alias="@type")
    proxy_id: int

    @staticmethod
    def read(q: dict) -> EnableProxy:
        return EnableProxy.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import PhoneNumberAuthenticationSettings


class SendPhoneNumberVerificationCode(BaseObject):
    """
    Sends a code to verify a phone number to be added to a user's Telegram Passport
    
    Params:
        phone_number (:class:`str`)
            The phone number of the user, in international format
        
        settings (:class:`PhoneNumberAuthenticationSettings`)
            Settings for the authentication of the user's phone number
        
    """

    ID: str = Field("sendPhoneNumberVerificationCode", alias="@type")
    phone_number: str
    settings: PhoneNumberAuthenticationSettings

    @staticmethod
    def read(q: dict) -> SendPhoneNumberVerificationCode:
        return SendPhoneNumberVerificationCode.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import UserPrivacySetting
from ..types import UserPrivacySettingRules


class SetUserPrivacySettingRules(BaseObject):
    """
    Changes user privacy settings
    
    Params:
        setting (:class:`UserPrivacySetting`)
            The privacy setting
        
        rules (:class:`UserPrivacySettingRules`)
            The new privacy rules
        
    """

    ID: str = Field("setUserPrivacySettingRules", alias="@type")
    setting: UserPrivacySetting
    rules: UserPrivacySettingRules

    @staticmethod
    def read(q: dict) -> SetUserPrivacySettingRules:
        return SetUserPrivacySettingRules.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class EmailAddressAuthenticationCodeInfo(BaseObject):
    """
    Information about the email address authentication code that was sent
    
    Params:
        email_address_pattern (:class:`str`)
            Pattern of the email address to which an authentication code was sent
        
        length (:class:`int`)
            Length of the code; 0 if unknown
        
    """

    ID: str = Field("emailAddressAuthenticationCodeInfo", alias="@type")
    email_address_pattern: str
    length: int

    @staticmethod
    def read(q: dict) -> EmailAddressAuthenticationCodeInfo:
        return EmailAddressAuthenticationCodeInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .formatted_text import FormattedText
from ..base_object import BaseObject


class DeepLinkInfo(BaseObject):
    """
    Contains information about a tg: deep link
    
    Params:
        text (:class:`FormattedText`)
            Text to be shown to the user
        
        need_update_application (:class:`bool`)
            True, if user should be asked to update the application
        
    """

    ID: str = Field("deepLinkInfo", alias="@type")
    text: FormattedText
    need_update_application: bool

    @staticmethod
    def read(q: dict) -> DeepLinkInfo:
        return DeepLinkInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatSource(BaseObject):
    """
    Describes a reason why an external chat is shown in a chat list
    
    """

    ID: str = Field("chatSource", alias="@type")


class ChatSourceMtprotoProxy(ChatSource):
    """
    The chat is sponsored by the user's MTProxy server
    
    """

    ID: str = Field("chatSourceMtprotoProxy", alias="@type")

    @staticmethod
    def read(q: dict) -> ChatSourceMtprotoProxy:
        return ChatSourceMtprotoProxy.construct(**q)


class ChatSourcePublicServiceAnnouncement(ChatSource):
    """
    The chat contains a public service announcement
    
    Params:
        type_ (:class:`str`)
            The type of the announcement
        
        text (:class:`str`)
            The text of the announcement
        
    """

    ID: str = Field("chatSourcePublicServiceAnnouncement", alias="@type")
    type_: str = Field(..., alias='type')
    text: str

    @staticmethod
    def read(q: dict) -> ChatSourcePublicServiceAnnouncement:
        return ChatSourcePublicServiceAnnouncement.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetSuitableDiscussionChats(BaseObject):
    """
    Returns a list of basic group and supergroup chats, which can be used as a discussion group for a channel. Returned basic group chats must be first upgraded to supergroups before they can be set as a discussion group. To set a returned supergroup as a discussion group, access to its old messages must be enabled using toggleSupergroupIsAllHistoryAvailable first
    
    """

    ID: str = Field("getSuitableDiscussionChats", alias="@type")

    @staticmethod
    def read(q: dict) -> GetSuitableDiscussionChats:
        return GetSuitableDiscussionChats.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .input_file import InputFile
from ..base_object import BaseObject


class InputChatPhoto(BaseObject):
    """
    Describes a photo to be set as a user profile or chat photo
    
    """

    ID: str = Field("inputChatPhoto", alias="@type")


class InputChatPhotoAnimation(InputChatPhoto):
    """
    An animation in MPEG4 format; must be square, at most 10 seconds long, have width between 160 and 800 and be at most 2MB in size
    
    Params:
        animation (:class:`InputFile`)
            Animation to be set as profile photo. Only inputFileLocal and inputFileGenerated are allowed
        
        main_frame_timestamp (:class:`float`)
            Timestamp of the frame, which will be used as static chat photo
        
    """

    ID: str = Field("inputChatPhotoAnimation", alias="@type")
    animation: InputFile
    main_frame_timestamp: float

    @staticmethod
    def read(q: dict) -> InputChatPhotoAnimation:
        return InputChatPhotoAnimation.construct(**q)


class InputChatPhotoPrevious(InputChatPhoto):
    """
    A previously used profile photo of the current user
    
    Params:
        chat_photo_id (:class:`int`)
            Identifier of the current user's profile photo to reuse
        
    """

    ID: str = Field("inputChatPhotoPrevious", alias="@type")
    chat_photo_id: int

    @staticmethod
    def read(q: dict) -> InputChatPhotoPrevious:
        return InputChatPhotoPrevious.construct(**q)


class InputChatPhotoStatic(InputChatPhoto):
    """
    A static photo in JPEG format
    
    Params:
        photo (:class:`InputFile`)
            Photo to be set as profile photo. Only inputFileLocal and inputFileGenerated are allowed
        
    """

    ID: str = Field("inputChatPhotoStatic", alias="@type")
    photo: InputFile

    @staticmethod
    def read(q: dict) -> InputChatPhotoStatic:
        return InputChatPhotoStatic.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckStickerSetName(BaseObject):
    """
    Checks whether a name can be used for a new sticker set
    
    Params:
        name (:class:`str`)
            Name to be checked
        
    """

    ID: str = Field("checkStickerSetName", alias="@type")
    name: str

    @staticmethod
    def read(q: dict) -> CheckStickerSetName:
        return CheckStickerSetName.construct(**q)
